Introduction
============

Before, using linchpin playbook collection , we'll learn about how to install ansible and linchpin dependencies.

.. toctree::
   :maxdepth: 1

   intro_installation
   intro_getting_started
